## dog

[rzeczownik]

1. pies

My dog has a very good sense of smell.
(Mój pies ma bardzo dobry węch.)

I walk my dog every day.
(Codziennie wyprowadzam mojego psa.)

I have a dog.
(Mam psa.)

This dog is big.
(Ten pies jest duży.)

2. samiec (psa, lisa, wilka)

These dogs can be aggressive.
(Te samce mogą być agresywne.)

Is it a dog or a bitch?
(To samiec czy suczka?)

3. łajdak, szuja

He's a dog, you can't trust him.
(To łajdak, nie możesz mu ufać.)

He tried to lie to me, what a dog!
(On próbował mnie okłamać, co za szuja!)

4. lipa, szmelc, tandeta

This equipment is a dog!
(Ten sprzęt to szmelc!)

She sells dogs.
(Ona sprzedaje tandetę.)

I won't give you even 10 dollars for this dog!
(Nie dam ci nawet dziesięciu dolarów za tę tandetę!)

5. pokraka, maszkara (nieatrakcyjna kobieta)

Look at that woman. What a dog.
(Popatrz na tamtą kobietę. Jaka pokraka.)

I love my sister, but I must admit that she's a dog.
(Kocham moją siostrę, ale muszę przyznać, że jest maszkarą.)

I married this dog because she's rich.
(Poślubiłem tę pokrakę, bo jest bogata.)

6. koleś, ziomek

That's Peter, my best dog.
(Poznaj Petera, mojego najlepszego ziomka.)

What's up, dog?
(Co tam, ziomek?)

7. pies na baby

Don't trust him, he's a real dog.
(Nie ufaj mu, to prawdziwy pies na baby.)

Women should stay away from him, he's a dog.
(Kobiety powinny trzymać się od niego z daleka, to pies na baby.)

8. dwója, pała (ocena)

I got a dog from that test.
(Dostałem pałę z tego testu.)

I have to read this book or I'll get a dog.
(Muszę przeczytać tę książkę, albo dostanę dwóję.)

[czasownik]

1. iść blisko za kimś (jak pies)

You have to dog him, I want to know where he lives!
(Musisz iść za nim blisko jak pies, chcę wiedzieć, gdzie on mieszka!)

This girl dogs me but I don't like her!
(Ta dziewczyna chodzi blisko za mną jak pies, ale ja jej nie lubię!)

2. gnębić (gdy kogoś gnębi jakiś problem lub pech)

Don't let it dog you, I'll help you find a job.
(Nie pozwól, żeby cię to gnębiło, pomogę ci znaleźć pracę.)

This problem has been dogging me for a year now.
(Ten problem gnębi mnie już od roku.)

3. uprawiać seks na pieska

I dogged Jane yesterday!
(Wczoraj uprawiałem z Jane seks na pieska!)

Jane doesn't like to dog.
(Jane nie lubi uprawiać seksu na pieska.)

4. nawalić, spieprzyć, schrzanić

Do not dog this, I won't give you another chance.
(Nie spieprz tego, nie dam ci kolejnej szansy.)

If you dog again, I'll have to break up with you.
(Jeśli znowu nawalisz, będę musiał z tobą zerwać.)

5. dołować, zamartwiać

You can't dog your mother, don't tell her about the accident.
(Nie możesz dołować swojej matki, nie mów jej o wypadku.)

I don't want to dog you, but I think we have a serious problem with our son.
(Nie chcę cię zamartwiać, ale myślę, że mamy poważny problem z naszym synem.)

## dog it

[idiom]

1. olewać, nie dawać z siebie wszystkiego

He was accused of dogging it by his boss.
(On został oskarżony o nie dawanie z siebie wszystkiego przez swojego szefa.)